==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/history/translations/history_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Historie rozhovorů</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Uložit zprávy v historii</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Uložit rozhovory s neznámými uživateli</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Změny stavu</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Uložit změny stavu</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Uložit změny stavu v historii</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Uložit stav pouze s popisem</translation>
    </message>
    <message>
        <source>Quotation</source>
        <translation>Citace</translation>
    </message>
    <message>
        <source>Quote message in chat window</source>
        <translation>Citovat zprávu v okně s rozhovorem</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Zobrazit historii</translation>
    </message>
    <message>
        <source>Do not quote messages older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished">Kadu</translation>
    </message>
</context>
<context>
    <name>BuddyStatusDatesModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
</context>
<context>
    <name>ChatDatesModel</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>View Chat History</source>
        <translation>Zobrazit historii rozhovoru</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Smazat historii</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Ukázat poslední %1 zprávy</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Ukázat zprávy od včerejška</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Ukázat zprávy z posledních sedmi dní</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Ukázat zprávy z posledních třiceti dní</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Ukázat celou historii</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>%1 den(y) %2 hodina(y)</translation>
    </message>
</context>
<context>
    <name>HistoryChatsModel</name>
    <message>
        <source>Statuses</source>
        <translation>Stavy</translation>
    </message>
    <message>
        <source>SMSes</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Odstranit záznamy</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>by date</source>
        <translation>podle data</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Od</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Do</translation>
    </message>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Smazat historii rozhovoru</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Smazat stavovou historii</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Smazat historii SMS</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>There is no history storage module loaded!</source>
        <translation>Není nahrán žádný modul pro ukládání historie!</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Chat history</source>
        <translation>Historie rozhovoru</translation>
    </message>
</context>
<context>
    <name>SmsDatesModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
</context>
</TS>

==> kadu_0.11.1.orig.tar.bz2: kadu-0.11.1/plugins/history/translations/history_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Historie rozhovorů</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Uložit zprávy v historii</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Uložit rozhovory s neznámými uživateli</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Změny stavu</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Uložit změny stavu</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Uložit změny stavu v historii</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Uložit stav pouze s popisem</translation>
    </message>
    <message>
        <source>Quotation</source>
        <translation>Citace</translation>
    </message>
    <message>
        <source>Quote message in chat window</source>
        <translation>Citovat zprávu v okně s rozhovorem</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Zobrazit historii</translation>
    </message>
    <message>
        <source>Do not quote messages older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished">Kadu</translation>
    </message>
</context>
<context>
    <name>BuddyStatusDatesModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
</context>
<context>
    <name>ChatDatesModel</name>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation>Smazat historii</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>%1 den(y) %2 hodina(y)</translation>
    </message>
</context>
<context>
    <name>HistoryChatsModel</name>
    <message>
        <source>Statuses</source>
        <translation>Stavy</translation>
    </message>
    <message>
        <source>SMSes</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Odstranit záznamy</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>by date</source>
        <translation>podle data</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Od</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Do</translation>
    </message>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Smazat historii rozhovoru</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Smazat stavovou historii</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Smazat historii SMS</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>There is no history storage plugin loaded!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Chat history</source>
        <translation>Historie rozhovoru</translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation>Zobrazit historii rozhovoru</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Ukázat poslední %1 zprávy</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Ukázat zprávy od včerejška</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Ukázat zprávy z posledních sedmi dní</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Ukázat zprávy z posledních třiceti dní</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Ukázat celou historii</translation>
    </message>
</context>
<context>
    <name>SmsDatesModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
</context>
</TS>
